package com.ynet.life.search.core;

import java.util.Arrays;
import org.apache.lucene.search.BooleanClause;

/* loaded from: com_ynet_life_search_core.jar:com/ynet/life/search/core/QueryStringParser.class */
public class QueryStringParser {
    private static final String QUERY_SEPERATOR = " ";
    private static final String FIELD_SEPERATOR = ":";
    private static final String MUST = "+";
    private static final String MUST_NOT = "-";
    private String[] fields;
    private String[] queries;
    private BooleanClause.Occur[] occurs;

    public void parse(String queryString) {
        String[] multiField = queryString.split(QUERY_SEPERATOR);
        int k = 0;
        String[] fieldBuf = new String[multiField.length];
        String[] queryBuf = new String[multiField.length];
        for (int i = 0; i < multiField.length; i++) {
            int index = multiField[i].indexOf(FIELD_SEPERATOR);
            if (index != -1) {
                String field = multiField[i].substring(0, index);
                String query = multiField[i].substring(index + 1, multiField[i].length());
                if (field != null && query != null) {
                    String field2 = field.trim();
                    String query2 = query.trim();
                    if (field2.length() != 0 && query2.length() != 0 && (field2.length() != 1 || (!MUST.equals(field2) && !MUST_NOT.equals(field2)))) {
                        fieldBuf[k] = field2;
                        queryBuf[k] = query2;
                        k++;
                    }
                }
            }
        }
        this.fields = new String[k];
        this.queries = new String[k];
        this.occurs = new BooleanClause.Occur[k];
        for (int i2 = 0; i2 < k; i2++) {
            String occur = fieldBuf[i2].substring(0, 1);
            if (MUST.equals(occur)) {
                this.fields[i2] = fieldBuf[i2].substring(1);
                this.occurs[i2] = BooleanClause.Occur.MUST;
            } else if (MUST_NOT.equals(occur)) {
                this.fields[i2] = fieldBuf[i2].substring(1);
                this.occurs[i2] = BooleanClause.Occur.MUST_NOT;
            } else {
                this.fields[i2] = fieldBuf[i2];
                this.occurs[i2] = BooleanClause.Occur.SHOULD;
            }
            this.queries[i2] = queryBuf[i2];
        }
    }

    public String[] getFields() {
        return this.fields;
    }

    public String[] getQueries() {
        return this.queries;
    }

    public BooleanClause.Occur[] getOccurs() {
        return this.occurs;
    }

    public static void main(String[] args) {
        QueryStringParser parser = new QueryStringParser();
        parser.parse("-bankType:314 cityCode:3052 +provinceCode:320 +fullContents:农村商业银行");
        System.out.println("Fields: " + Arrays.toString(parser.getFields()));
        System.out.println("Queries: " + Arrays.toString(parser.getQueries()));
        System.out.println("Occurs: " + Arrays.toString(parser.getOccurs()));
    }
}
